<?php
namespace app\index\controller;

use app\api\controller\index;
use app\index\model\Player;
use app\index\model\SongSheet;
use app\index\model\Song;
use app\index\model\User;

use think\Db;
use think\Cache;
use think\Session;

class PlayerAjax extends Ajax
{
	/**
     * 更新播放器
     */
    public function editPlayer()
    {
		if (request()->isAjax()) {
		$data = input('post.');
        // 删除api缓存
        Cache::rm('info'.$data['id']);

        model('Player')->save($data,
            ['id'=> $data['id']]);
		}
			$result = [
						'code' => 0,
						'msg' => '保存成功[已清理缓存]'
					];
        return $result;
    }
	
	/**
     * 删除播放器
     * @throws \Exception
     */
    public function delPlayer()
    {
		if (request()->isAjax()) {
		$userInfo = User::getLoginUser();
		$data = input('post.');
		Cache::rm('info'.$data['id']);
        // 删除歌单关联项
        model('PlayerSongSheet')->where('player_id',$data['id'])->delete();
        // 删除播放器
        model('Player')->where('id',$data['id'])->delete();
		$pie = array(
					'pie' => $userInfo['pie'] + 1,
					);
					User::updateByUid($userInfo['uid'],$pie);
        $result = [
						'code' => 0,
						'msg' => '删除成功'
					];
		}
		return $result;
    }
	
	public function delSheet()
    {
		if (request()->isAjax()) {
		$data = input('post.');
		$players = SongSheet::songSheetPlayers($data['id']);
				if(count($players) > 0){
					foreach ($players as $value){
						// 删除api缓存
						Cache::rm('info'.$value->player_id);
					}
				}
		// 删除歌单音乐
        model('Song')->where('song_sheet_id', $data['id'])->delete();
        // 删除歌单关联项
        model('PlayerSongSheet')->where('song_sheet_id',$data['id'])->delete();
        // 删除歌单
        model('SongSheet')->where('id',$data['id'])->delete();
        $result = [
						'code' => 0,
						'msg' => '删除成功'
					];
		}
		return $result;
    }
	
	/**
     * 搜索歌曲
     * @param $type string 歌曲类型
     * @param $songName string 歌曲名称
     * @param int $page int 页码
     */
    public function searchSong($type, $songName,$page = 1){
        $musicApi = new index();
        $songs = [];
        switch ($type) {
            case 'wy':
                $songs = $musicApi->get_song_by_name($songName,'netease',$page);
                break;
            case  'kg':
                $songs = $musicApi->get_song_by_name($songName,'kugou',$page);
                break;
        }
        $this->success('获取成功','',$songs);
    }
	
	public function checkSonginfo()
	{
		if (request()->isAjax()) {
		$data = input('post.');
		$rule=[
            'name'  => 'require',
			'album_name'  => 'require',
			'artist_name'  => 'require',
			'album_cover'  => 'require',
			'location'  => 'require',
        ];
        $message=[
            'name.require'=>'歌曲名称不能为空',
			'album_name.require'=>'专辑名称不能为空',
			'artist_name.require'=>'作者名称不能为空',
			'album_cover.require'=>'专辑封面地址不能为空',
			'location.require'=>'歌曲播放地址不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}else{
					$result = [
						'code' => 0,
						'name'  => $data['name'],
						'album_name'  => $data['album_name'],
						'artist_name'  => $data['artist_name'],
						'album_cover'  => $data['album_cover'],
						'location'  => $data['location'],
						'lyric'  => $data['lyric'],
					];
			}
		}
        return $result;
    }
	
	public function Songinfo()
	{
		if (request()->isAjax()) {
		$data = input('post.');
		$rule=[
            'songid'  => 'require',
        ];
        $message=[
            'songid.require'=>'歌曲ID不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}else{
			$json = Song::findMusicInfo($data);
			if($json==''){
				$result = [
						'code' => -1,
						'msg' => '未找到任何歌曲'
					];
			}else{
				$result = $json;
			}	
			}
		}
        return $result;
    }
	
	public function SheetInfo()
	{
		if (request()->isAjax()) {
		$userInfo = User::getLoginUser();
		$data = input('post.');
		$rule=[
            'sheetid'  => 'require',
        ];
        $message=[
            'sheetid.require'=>'歌单ID不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}else{
				$songs = Song::findSheetInfo($data['type'],$data['sheetid']);
				if($songs==''){
				$result = [
						'code' => -1,
						'msg' => '未找到任何歌单'
					];
				}else{
					$result = [
					'code' => 0,
					'msg' => '添加成功',
					'songs' => $songs
					];
				}	
				
			}
		}
        return $result;
    }
	
	public function SetSheet()
	{
		if (request()->isAjax()) {
		$userInfo = User::getLoginUser();
		$data = input('post.');
		$rule=[
            'name'  => 'require',
        ];
        $message=[
            'name.require'=>'歌单名称不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}elseif(SongSheet::checkSheetUid($data['id'],$userInfo['uid'])== true){
			$result = [
						'code' => -1,
						'msg' => '没有权限',
					];
		}else{
				$players = SongSheet::songSheetPlayers($data['id']);
				if(count($players) > 0){
					foreach ($players as $value){
						// 删除api缓存
						Cache::rm('info'.$value->player_id);
					}
				}
				SongSheet::set($data);
				$result = [
					'code' => 0,
					'msg' => '保存成功[缓存已清除]',
				];
			}
		}
        return $result;
    }
	
	/**
     * 克隆歌单
     */
    public function Sheetkl()
    {
		if (request()->isAjax()) {
		$userInfo = User::getLoginUser();
		$key = input('post.songSheetId');
		$jsonData = $_POST['jsonData'];
		$entity = model('SongSheet')->where("id",$key)->find();
		$entity['user_id'] = $userInfo['uid'];
		$entity['id'] = uniqid();
		SongSheet::kladd($entity);
		
		
		$songModel = model('Song');

        // 重新保存歌曲列表
        $array = json_decode($jsonData, true);
        foreach ($array as $key => $value) {
            $value['song_sheet_id'] = $entity['id'];
            $value['id'] = uniqid();
            $array[$key] = $value;
        }
        $songModel->saveAll($array, false);
		
		$result = [
					'code' => 0,
					'msg' => '克隆成功',
				];
        return $result;
		}
    }
	
	public function AddPlayer()
	{
		if (request()->isAjax()) {
		$userInfo = User::getLoginUser();
		$data = input('post.');
		$rule=[
            'name'  => 'require',
        ];
        $message=[
            'name.require'=>'播放器名称不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}elseif($userInfo['pie'] < 1){
					$result = [
						'code' => -1,
						'msg' => '播放器配额不足1个',
					];
		}elseif(Player::add($data)){
			        $pie = array(
					'pie' => $userInfo['pie'] - 1,
					);
					User::updateByUid($userInfo['uid'],$pie);
					$result = [
						'code' => 0,
						'msg' => '添加成功',
						'url' => url('home/playerlist'),
					];
			}
		}
        return $result;
    }
	
	public function editSongSheetSong()
    {
		$jsonData = $_POST['jsonData'];
		$songSheetId = $_POST['songSheetId'];
        // 清除缓存
        $players = SongSheet::songSheetPlayers($songSheetId);
        if(count($players) > 0){
            foreach ($players as $value){
                // 删除api缓存
                Cache::rm('info'.$value->player_id);
            }
        }

        // 删除播放器之前的歌曲
        $songModel = model('Song');
        $songModel->where('song_sheet_id', $songSheetId)->delete();

        // 重新保存歌曲列表
        $array = json_decode($jsonData, true);
        foreach ($array as $key => $value) {
            $value['song_sheet_id'] = $songSheetId;
            $value['id'] = uniqid();
            $array[$key] = $value;
        }
        $songModel->saveAll($array, false);

        $result = [
						'code' => 0,
						'msg' => '保存成功',
					];
		return $result;
    }

    public function AddSongSheet()
	{
		if (request()->isAjax()) {
		$data = input('post.');
		$rule=[
            'name'  => 'require',
        ];
        $message=[
            'name.require'=>'歌单名称不能为空',
        ];
        $validate=new \think\Validate($rule,$message);
        if(!$validate->check($data)){
			$result = [
						'code' => -1,
						'msg' => $validate->getError()
					];
		}elseif(SongSheet::add($data)){
					$result = [
						'code' => 0,
						'msg' => '添加成功',
						'url' => url('home/sheetlist'),
					];
			}
		}
        return $result;
    }
	
	public function editPlayerSongSheet()
	{
		if (request()->isAjax()) {
		$data = input('post.');
		$userInfo = User::getLoginUser();
		if(Player::checkPlayerUid($data['playerId'],$userInfo['uid'])== true){
			$result = [
						'code' => -1,
						'msg' => '没有权限'
					];
		}else{
		Cache::rm('info'.$data['playerId']);
        $ids = $this->request->post('ids/a');

        // 删除之前的关联
        Db('player_song_sheet')->where('player_id',$data['playerId'])->delete();

        if($ids != null){
            $joins = [];
            for($i = 0;$i < count($ids);$i++){
                $joins[$i] = ['player_id' => $data['playerId'],'song_sheet_id' => $ids[$i],'taxis'=>$i];
            }

            //插入编辑之后的数据
            Db('player_song_sheet')->insertAll($joins);
        }
		$result = [
						'code' => 0,
						'msg' => '保存成功[缓存已清除]'
					];
		}
		}
        return $result;
    }
	
	public function getksc()
	{
		if (request()->isAjax()) {
			$keyword=input('post.keyword');
			if(!$keyword){
			$result = [
				'code' => -1,
				'con'  => '参数为空'
			];
			}else{
			$ksc=get_curl(ksc_api().'?keyword='. $keyword);
			$result = [
				'code' => 0,
				'con'  => $ksc
			];
			}
        return $result;
		}
	}
	
	public function Logout()
	{
		if (request()->isAjax()) {
			if(User::logout()){
					$result = [
						'code' => 0,
						'msg' => '退出成功'
					];
			}
		}
        return $result;
    }
	
	protected
    function _initialize()
    {
            $this->checkLogin();
    }

    private
    function checkLogin()
    {
        $check_Login = User::checkLogin();
        if ($check_Login != null) {
            $this->assign('alert', $check_Login['msg']);
            $this->assign('url', $check_Login['url']);
            exit($this->fetch('common/sweetalert'));
        } else {
            $this->userInfo = User::getLoginUser();
            $this->assign('userInfo', $this->userInfo);

        }
    }
}